@@ -52,11 +52,9 @@ class RepoSpider(CrawlSpider, ABC):
             path
 
     ):
-        super().__init__()
+        super().__init__(RepoSpider.name)
         self.start_urls = url
-
         self.pointer = path
-
         self.manager = concurrent.futures.ThreadPoolExecutor(
             max_workers=min(32, os.cpu_count() + 4),
             thread_name_prefix="Downloads"
